summaryrefslogtreecommitdiff
path: root/arch/arm/mach-tegra/hotplug.c
diff options
context:
space:
mode:
authorDan Willemsen <dwillemsen@nvidia.com>2013-07-29 13:38:25 -0700
committerDan Willemsen <dwillemsen@nvidia.com>2013-09-13 22:43:23 -0700
commitd1c368418e30f9230d8bc021a2d9adef0bd381e4 (patch)
tree782593627fbbe91cf3a66693d8b55045ecdc6390 /arch/arm/mach-tegra/hotplug.c
parent59327d14193e43612305bbb959e01be12194a65b (diff)
Revert "ARM: tegra: update the cache maintenance order for CPU shutdown"
This reverts commit 57886616ca7bff844a6427436d0c8faf74653f73. Signed-off-by: Dan Willemsen <dwillemsen@nvidia.com>
Diffstat (limited to 'arch/arm/mach-tegra/hotplug.c')
-rw-r--r--arch/arm/mach-tegra/hotplug.c4
1 files changed, 2 insertions, 2 deletions
diff --git a/arch/arm/mach-tegra/hotplug.c b/arch/arm/mach-tegra/hotplug.c
index 13f170b28605..6fc3cd2461bf 100644
--- a/arch/arm/mach-tegra/hotplug.c
+++ b/arch/arm/mach-tegra/hotplug.c
@@ -28,8 +28,8 @@ void __ref tegra_cpu_die(unsigned int cpu)
{
cpu = cpu_logical_map(cpu);
- /* Clean L1 data cache */
- tegra_disable_clean_inv_dcache();
+ /* Flush the L1 data cache. */
+ flush_cache_all();
/* Shut down the current CPU. */
tegra_hotplug_shutdown();